@@ -32,9 +32,12 @@
 #define _GNUstep_H_NSPasteboard
 #import <GNUstepBase/GSVersionMacros.h>
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSString.h>
-#include <AppKit/AppKitDefines.h>
+#import <Foundation/NSObject.h>
+#import <AppKit/AppKitDefines.h>
+
+#if defined(__cplusplus)
+extern "C" {
+#endif
 
 @class NSString;
 @class NSArray;
@@ -172,6 +175,26 @@ APPKIT_EXPORT NSString *NSRulerPboard;
  */
 APPKIT_EXPORT NSString *NSPasteboardCommunicationException;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+APPKIT_EXPORT NSString *const NSPasteboardTypeString;
+APPKIT_EXPORT NSString *const NSPasteboardTypePDF;
+APPKIT_EXPORT NSString *const NSPasteboardTypeTIFF;
+APPKIT_EXPORT NSString *const NSPasteboardTypePNG;
+APPKIT_EXPORT NSString *const NSPasteboardTypeRTF;
+APPKIT_EXPORT NSString *const NSPasteboardTypeRTFD;
+APPKIT_EXPORT NSString *const NSPasteboardTypeHTML;
+APPKIT_EXPORT NSString *const NSPasteboardTypeTabularText;
+APPKIT_EXPORT NSString *const NSPasteboardTypeFont;
+APPKIT_EXPORT NSString *const NSPasteboardTypeRuler;
+APPKIT_EXPORT NSString *const NSPasteboardTypeColor;
+APPKIT_EXPORT NSString *const NSPasteboardTypeSound;
+APPKIT_EXPORT NSString *const NSPasteboardTypeMultipleTextSelection;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+APPKIT_EXPORT NSString *const NSPasteboardTypeTextFinderOptions;
+#endif
+#endif
+
 
 @interface NSPasteboard : NSObject
 {
@@ -285,7 +308,7 @@ APPKIT_EXPORT NSString *NSPasteboardCommunicationException;
 @end
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
-#include <Foundation/NSURL.h>
+#import <Foundation/NSURL.h>
 
 @interface NSURL (NSPasteboard)
 + (NSURL*) URLFromPasteboard: (NSPasteboard*)pasteBoard;
@@ -301,5 +324,53 @@ APPKIT_EXPORT NSString *NSCreateFilenamePboardType(NSString *fileType);
 APPKIT_EXPORT NSString *NSGetFileType(NSString *pboardType);
 APPKIT_EXPORT NSArray *NSGetFileTypes(NSArray *pboardTypes);
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+typedef NSUInteger NSPasteboardWritingOptions;
+enum {
+  NSPasteboardWritingPromised = 1 << 9
+};
+
+@protocol NSPasteboardWriting <NSObject>
+- (NSArray *)writableTypesForPasteboard: (NSPasteboard *)pasteboard;
+- (id)pasteboardPropertyListForType: (NSString *)type;
+
+#if GS_PROTOCOLS_HAVE_OPTIONAL
+@optional
+#else
+@end
+@interface NSObject (NSPasteboardWriting)
+#endif
+
+- (NSPasteboardWritingOptions)writingOptionsForType: (NSString *)type
+					 pasteboard: (NSPasteboard *)pasteboard;
+@end
+
+typedef NSUInteger NSPasteboardReadingOptions;
+enum {
+  NSPasteboardReadingAsData           = 0,
+  NSPasteboardReadingAsString         = 1 << 0,
+  NSPasteboardReadingAsPropertyList   = 1 << 1,
+  NSPasteboardReadingAsKeyedArchive   = 1 << 2
+};
+
+@protocol NSPasteboardReading <NSObject>
++ (NSArray *)readableTypesForPasteboard:(NSPasteboard *)pasteboard;
+
+#if GS_PROTOCOLS_HAVE_OPTIONAL
+@optional
+#else
+@end
+@interface NSObject (NSPasteboardReading)
+#endif
+
++ (NSPasteboardReadingOptions)readingOptionsForType: (NSString *)type
+				         pasteboard: (NSPasteboard *)pasteboard;
+- (id)initWithPasteboardPropertyList: (id)propertyList ofType: (NSString *)type;
+@end
+#endif
+
+#if defined(__cplusplus)
+}
+#endif
 
 #endif // _GNUstep_H_NSPasteboard
