@@ -2,7 +2,7 @@
 
    <abstract>Encapsulates all drawing functionality</abstract>
 
-   Copyright <copy>(C) 1996 Free Software Foundation, Inc.</copy>
+   Copyright <copy>(C) 1996-2015 Free Software Foundation, Inc.</copy>
 
    Author:  Scott Christley <scottc@net-community.com>
    Date: 1996
@@ -36,6 +36,7 @@
 
 #import <AppKit/NSGraphicsContext.h>
 #import <AppKit/NSResponder.h>
+#import <AppKit/NSUserInterfaceLayout.h>
 
 @class NSArray;
 @class NSAttributedString;
@@ -53,8 +54,8 @@
 @class NSView;
 @class NSWindow;
 
-typedef int NSTrackingRectTag;
-typedef int NSToolTipTag;
+typedef NSInteger NSTrackingRectTag;
+typedef NSInteger NSToolTipTag;
 
 /** Describes the type of border used by an NSView.
   <list>
@@ -64,12 +65,38 @@ typedef int NSToolTipTag;
    <item>NSGrooveBorder</item>
   </list>
 */
-typedef enum _NSBorderType {
+enum _NSBorderType {
   NSNoBorder,
   NSLineBorder,
   NSBezelBorder,
   NSGrooveBorder
-} NSBorderType;
+};
+typedef NSUInteger NSBorderType;
+
+typedef NSInteger NSViewLayerContentsRedrawPolicy;
+enum {
+  NSViewLayerContentsRedrawNever = 0,
+  NSViewLayerContentsRedrawOnSetNeedsDisplay = 1,
+  NSViewLayerContentsRedrawDuringViewResize = 2,
+  NSViewLayerContentsRedrawBeforeViewResize = 3,
+  NSViewLayerContentsRedrawCrossfade = 4
+};
+
+typedef NSInteger NSViewLayerContentsPlacement;
+enum {
+  NSViewLayerContentsPlacementScaleAxesIndependently = 0,
+  NSViewLayerContentsPlacementScaleProportionallyToFit = 1,
+  NSViewLayerContentsPlacementScaleProportionallyToFill = 2,
+  NSViewLayerContentsPlacementCenter = 3,
+  NSViewLayerContentsPlacementTop = 4,
+  NSViewLayerContentsPlacementTopRight = 5,
+  NSViewLayerContentsPlacementRight = 6,
+  NSViewLayerContentsPlacementBottomRight = 7,
+  NSViewLayerContentsPlacementBottom = 8,
+  NSViewLayerContentsPlacementBottomLeft = 9,
+  NSViewLayerContentsPlacementLeft = 10,
+  NSViewLayerContentsPlacementTopLeft = 11
+};
 
 /*
  * autoresize constants which NSView uses in
@@ -115,23 +142,17 @@ PACKAGE_SCOPE
 @protected
   NSRect _invalidRect;
   NSRect _visibleRect;
-  int _gstate;
+  NSInteger _gstate;
   void *_nextKeyView;
   void *_previousKeyView;
+  CGFloat _alphaValue;
 
 @public
   /*
    * Flags for internal use by NSView and it's subclasses.
    */
   struct _rFlagsType {
-    /*
-     * 'flipped_view' is set in NSViews designated initialiser (and other
-     * methods that create views) to be the value returned by [-isFlipped]
-     * This caching assumes that the value returned by [-isFlipped] will
-     * not change during the views lifetime - if it does, the view must
-     * be sure to change the flag accordingly.
-     */
-    unsigned	flipped_view:1;
+    unsigned	flipped_view:1;         /* Flipped state the last time we checked. */ 
     unsigned	has_subviews:1;		/* The view has subviews.	*/
     unsigned	has_currects:1;		/* The view has cursor rects.	*/
     unsigned	has_trkrects:1;		/* The view has tracking rects.	*/
@@ -156,8 +177,9 @@ PACKAGE_SCOPE
   BOOL _is_hidden;
   BOOL _in_live_resize;
 
-  unsigned int _autoresizingMask;
+  NSUInteger _autoresizingMask;
   NSFocusRingType _focusRingType;
+  NSRect _autoresizingFrameError;
 }
 
 /*
@@ -182,9 +204,12 @@ PACKAGE_SCOPE
 #endif
 - (void) replaceSubview: (NSView*)oldView
                    with: (NSView*)newView;
-- (void) sortSubviewsUsingFunction: (int (*)(id ,id ,void*))compare
+- (void) sortSubviewsUsingFunction: (NSComparisonResult (*)(id ,id ,void*))compare
 			   context: (void*)context;
 - (NSArray*) subviews;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (void) setSubviews: (NSArray *)newSubviews;
+#endif
 - (NSView*) superview;
 - (NSWindow*) window;
 - (void) viewWillMoveToSuperview: (NSView*)newSuper;
@@ -205,31 +230,42 @@ PACKAGE_SCOPE
 /*
  * Modifying the Frame Rectangle
  */
-- (float) frameRotation;
+- (CGFloat) frameRotation;
 - (NSRect) frame;
 - (void) setFrame: (NSRect)frameRect;
 - (void) setFrameOrigin: (NSPoint)newOrigin;
-- (void) setFrameRotation: (float)angle;
+- (void) setFrameRotation: (CGFloat)angle;
 - (void) setFrameSize: (NSSize)newSize;
 
 /*
  * Modifying the Coordinate System
  */
-- (float) boundsRotation;
+- (CGFloat) boundsRotation;
 - (NSRect) bounds;
 - (void) setBounds: (NSRect)aRect;
 - (void) setBoundsOrigin: (NSPoint)newOrigin;
-- (void) setBoundsRotation: (float)angle;
+- (void) setBoundsRotation: (CGFloat)angle;
 - (void) setBoundsSize: (NSSize)newSize;
 
 - (void) translateOriginToPoint: (NSPoint)point;
 - (void) scaleUnitSquareToSize: (NSSize)newSize;
-- (void) rotateByAngle: (float)angle;
+- (void) rotateByAngle: (CGFloat)angle;
 
 - (BOOL) isFlipped;
 - (BOOL) isRotatedFromBase;
 - (BOOL) isRotatedOrScaledFromBase;
 
+/*
+ * View Layers
+ */
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (CGFloat) alphaValue;
+- (void) setAlphaValue: (CGFloat)alpha;
+- (CGFloat) frameCenterRotation;
+- (void) setFrameCenterRotation:(CGFloat)rot;
+#endif
+
 /*
  * Converting Coordinates
  */
@@ -246,6 +282,14 @@ PACKAGE_SCOPE
 	      fromView: (NSView*)aView;
 - (NSSize) convertSize: (NSSize)aSize
 		toView: (NSView*)aView;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (NSPoint) convertPointFromBase: (NSPoint)aPoint;
+- (NSPoint) convertPointToBase: (NSPoint)aPoint;
+- (NSRect) convertRectFromBase: (NSRect)aRect;
+- (NSRect) convertRectToBase: (NSRect)aRect;
+- (NSSize) convertSizeFromBase: (NSSize)aSize;
+- (NSSize) convertSizeToBase: (NSSize)aSize;
+#endif
 
 /*
  * Notifying Ancestor Views
@@ -261,8 +305,8 @@ PACKAGE_SCOPE
 - (void) resizeSubviewsWithOldSize: (NSSize)oldSize;
 - (void) setAutoresizesSubviews: (BOOL)flag;
 - (BOOL) autoresizesSubviews;
-- (void) setAutoresizingMask: (unsigned int)mask;
-- (unsigned int) autoresizingMask;
+- (void) setAutoresizingMask: (NSUInteger)mask;
+- (NSUInteger) autoresizingMask;
 - (void) resizeWithOldSuperviewSize: (NSSize)oldSize;
 
 /*
@@ -323,7 +367,7 @@ PACKAGE_SCOPE
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 - (BOOL) wantsDefaultClipping;
 - (BOOL) needsToDrawRect: (NSRect)aRect;
-- (void) getRectsBeingDrawn: (const NSRect **)rects count: (int *)count;
+- (void) getRectsBeingDrawn: (const NSRect **)rects count: (NSInteger *)count;
 
 /*
  * Live resize support
@@ -334,7 +378,7 @@ PACKAGE_SCOPE
 #endif
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
 - (BOOL) preservesContentDuringLiveResize;
-- (void) getRectsExposedDuringLiveResize: (NSRect[4])exposedRects count: (int *)count;
+- (void) getRectsExposedDuringLiveResize: (NSRect[4])exposedRects count: (NSInteger *)count;
 - (NSRect) rectPreservedDuringLiveResize;
 #endif
 
@@ -344,7 +388,7 @@ PACKAGE_SCOPE
  */
 - (void) allocateGState;
 - (void) releaseGState;
-- (int) gState;
+- (NSInteger) gState;
 - (void) renewGState;
 - (void) setUpGState;
 
@@ -516,23 +560,23 @@ PACKAGE_SCOPE
 /*
  * Pagination
  */
-- (void) adjustPageHeightNew: (float*)newBottom
-                         top: (float)oldTop
-                      bottom: (float)oldBottom
-                       limit: (float)bottomLimit;
-- (void) adjustPageWidthNew: (float*)newRight
-                       left: (float)oldLeft
-                      right: (float)oldRight
-                      limit: (float)rightLimit;
-- (float) heightAdjustLimit;
+- (void) adjustPageHeightNew: (CGFloat*)newBottom
+                         top: (CGFloat)oldTop
+                      bottom: (CGFloat)oldBottom
+                       limit: (CGFloat)bottomLimit;
+- (void) adjustPageWidthNew: (CGFloat*)newRight
+                       left: (CGFloat)oldLeft
+                      right: (CGFloat)oldRight
+                      limit: (CGFloat)rightLimit;
+- (CGFloat) heightAdjustLimit;
 - (BOOL) knowsPagesFirst: (int*)firstPageNum
                     last: (int*)lastPageNum;
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (BOOL) knowsPageRange: (NSRange*)range;
 #endif
 - (NSPoint) locationOfPrintRect: (NSRect)aRect;
-- (NSRect) rectForPage: (int)page;
-- (float) widthAdjustLimit;
+- (NSRect) rectForPage: (NSInteger)page;
+- (CGFloat) widthAdjustLimit;
 
 /*
  * Writing Conforming PostScript
@@ -572,6 +616,28 @@ PACKAGE_SCOPE
 - (NSAttributedString *)pageHeader;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+#if GS_HAS_DECLARED_PROPERTIES
+@property (nonatomic) NSViewLayerContentsPlacement layerContentsPlacement;
+@property (nonatomic) NSViewLayerContentsRedrawPolicy layerContentsRedrawPolicy;
+#else
+- (NSViewLayerContentsPlacement) layerContentsPlacement;
+- (void) setLayerContentsPlacement: (NSViewLayerContentsPlacement)placement;
+
+- (NSViewLayerContentsRedrawPolicy) layerContentsRedrawPolicy;
+- (void) setLayerContentsRedrawPolicy: (NSViewLayerContentsRedrawPolicy) pol;
+#endif
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_8, GS_API_LATEST)
+#if GS_HAS_DECLARED_PROPERTIES
+@property NSUserInterfaceLayoutDirection userInterfaceLayoutDirection;
+#else
+- (NSUserInterfaceLayoutDirection) userInterfaceLayoutDirection;
+- (void) setUserInterfaceLayoutDirection: (NSUserInterfaceLayoutDirection)dir;
+#endif
+#endif
+
 @end
 
 
