@@ -87,6 +87,13 @@ enum {
   NSScreenSaverWindowLevel = 1000  // 12
 };
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_9, GS_API_LATEST)
+enum {
+  NSModalResponseOK = 1,
+  NSModalResponseCancel = 0
+};
+#endif
+
 enum {
   NSBorderlessWindowMask = 0,
   NSTitledWindowMask = 1,
@@ -99,11 +106,50 @@ enum {
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
   NSUnscaledWindowMask = 2048,
   NSUnifiedTitleAndToolbarWindowMask = 4096,
-#endif 
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+  NSFullScreenWindowMask = 16384,
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
+  NSFullSizeContentViewWindowMask = 1 << 15,
+#endif
   NSIconWindowMask = 64,	/* GNUstep extension - app icon window	*/
   NSMiniWindowMask = 128	/* GNUstep extension - miniwindows	*/
 };
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+enum {
+  NSWindowCollectionBehaviorDefault = 0,
+  NSWindowCollectionBehaviorCanJoinAllSpaces = 1 << 0,
+  NSWindowCollectionBehaviorMoveToActiveSpace = 1 << 1
+};
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+enum {
+  NSWindowCollectionBehaviorManaged = 1 << 2,
+  NSWindowCollectionBehaviorTransient = 1 << 3,
+  NSWindowCollectionBehaviorStationary = 1 << 4,
+};
+enum {
+  NSWindowCollectionBehaviorParticipatesInCycle = 1 << 5,
+  NSWindowCollectionBehaviorIgnoresCycle = 1 << 6
+};
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+enum {
+  NSWindowCollectionBehaviorFullScreenPrimary = 1 << 7,
+  NSWindowCollectionBehaviorFullScreenAuxiliary = 1 << 8
+};
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_11, GS_API_LATEST)
+enum
+{
+  NSWindowCollectionBehaviorFullScreenAllowsTiling = 1 << 11,
+  NSWindowCollectionBehaviorFullScreenDisallowsTiling = 1 << 12
+};
+#endif
+typedef NSUInteger NSWindowCollectionBehavior;
+
 enum _NSSelectionDirection {
   NSDirectSelection,
   NSSelectingNext,
@@ -121,7 +167,7 @@ enum _NSWindowButton
   NSWindowDocumentIconButton
 };
 typedef NSUInteger NSWindowButton;
-#endif 
+#endif
 
 APPKIT_EXPORT NSSize NSIconSize;
 APPKIT_EXPORT NSSize NSTokenSize;
@@ -540,6 +586,11 @@ PACKAGE_SCOPE
 
 - (NSResponder*) firstResponder;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (NSWindowCollectionBehavior)collectionBehavior;
+- (void)setCollectionBehavior:(NSWindowCollectionBehavior)props;
+#endif
+
 /**
  * This method attempts to make aResponder the first responder.<br />
  * If aResponder is already the first responder, this method has no
@@ -737,7 +788,7 @@ PACKAGE_SCOPE
 #endif
 
 /*
- * Window butons
+ * Window buttons
  */
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
 + (NSButton *) standardWindowButton: (NSWindowButton)button 
@@ -773,6 +824,27 @@ PACKAGE_SCOPE
 - (void) setDisplaysWhenScreenProfileChanges: (BOOL)flag;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_9, GS_API_LATEST)
+#if GS_HAS_DECLARED_PROPERTIES
+@property (readonly) NSWindow *sheetParent;
+#else
+- (NSWindow *) sheetParent;
+#endif
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+#if GS_HAS_DECLARED_PROPERTIES
+@property (readonly) CGFloat backingScaleFactor;
+#else
+- (CGFloat) backingScaleFactor;
+#endif
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
++ (NSInteger)windowNumberAtPoint:(NSPoint)point
+     belowWindowWithWindowNumber:(NSInteger)windowNumber;
+#endif
+
 @end
 
 @class NSToolbar;
