@@ -32,15 +32,13 @@
 #ifndef _GSToolbarView_h_INCLUDE
 #define _GSToolbarView_h_INCLUDE
 
-#include <Foundation/NSGeometry.h>
-#include <AppKit/NSView.h>
-#include <AppKit/NSColor.h>
-
-#include "GNUstepGUI/GSToolbar.h"
-// Necessary for NSToolbarDisplayMode and NSToolbarSizeMode
+#import <Foundation/NSGeometry.h>
+#import <AppKit/NSView.h>
+#import <AppKit/NSColor.h>
 
 @class NSMutableArray;
 @class NSClipView;
+@class NSToolbar;
 @class NSToolbarItem;
 @class GSToolbarClippedItemsButton;
 
@@ -54,26 +52,22 @@ typedef enum {
 
 @interface GSToolbarView : NSView
 {
-  GSToolbar *_toolbar;
-  NSClipView *_clipView, *_clipViewForEditMode;
+  NSToolbar *_toolbar;
+  NSClipView *_clipView;
   GSToolbarClippedItemsButton *_clippedItemsMark;
-  NSMutableArray *_visibleBackViews;
-  BOOL _willBeVisible;
   unsigned int _borderMask;
-  NSToolbarDisplayMode _displayMode;
-  NSToolbarSizeMode _sizeMode;
   NSRect _rectAvailable;
   float _heightFromLayout;
 }
 
++ (NSUInteger) draggedItemIndex;
++ (void) setDraggedItemIndex:(NSUInteger)sourceIndex;
+
 - (id) initWithFrame: (NSRect)frame;
-- (id) initWithFrame: (NSRect)frame 
-         displayMode: (NSToolbarDisplayMode)displayMode 
-	    sizeMode: (NSToolbarSizeMode)sizeMode; 
 
 // Accessors
-- (GSToolbar *) toolbar;
-- (void) setToolbar: (GSToolbar *)toolbar;
+- (NSToolbar *) toolbar;
+- (void) setToolbar: (NSToolbar *)toolbar;
 - (unsigned int) borderMask;
 - (void) setBorderMask: (unsigned int)borderMask;
 
